%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
% Master M-File                                                           %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 1 Initialize the process
clear all
clc
path(path, 'P:\Lectures assisted\FS2015\Seminar Makro\Session3'); 

% CHECK YOUR DYNARE VERSION AND REPLACE [4.2.0] by your version
addpath c:\dynare\4.4.2\matlab

% CHOOSE MODEL YOU WANT TO SIMULATE
% OPTIONS
% 1: UTILITY: c^(1-sigma)/(1-sigma)-chi*n^(1+nu)/(1+nu)
% 2: UTILITY: ln(c)-chi*n^(1+nu)/(1+nu)

Sett.Options = [1 2];
for xx = 1:length(Sett.Options)
    Sett.model = xx;
    if Sett.model == 1
        disp('General separable utility')
    else
        disp('Log-separable utility')
    end
%--------------------------------------------------------------------------
%% 2 PARAMETERS
    % Structural parameters
        beta  = 0.99;   
        sigma = 2;      
        nu    = 2;      
        alpha = 0.35;   
        delta = 0.025;  
    % Exogenous technology
        ra    = 0.95;   
        sa    = 0.01;   
        Ass   = 1;    
    % Growth rate
        gamma   =   1.05;
%--------------------------------------------------------------------------
%% 3 STEADY STATE
    % Steady state labor
        nss     =   1/3;
    % Assisting steady states
        rs  = (gamma-beta*(1-delta))/beta;
        ksy = alpha/rs;
        isk = gamma+delta-1;
        isy = isk*ksy;
        csy = 1-isy;
        ns  = 1/3;
        ys  = ksy^(alpha/(1-alpha))*ns;
        cs  = csy*ys;
        is  = isy*ys;
        ks  = ksy*ys;
        ws  = (1-alpha)*ys/ns;

if Sett.model == 1 
    lbs = cs^(-sigma);
else 
    lbs = cs^(-1);
end

    % Theta is such that nss=1/3
    chi = lbs*ws*ns^(-nu);
%--------------------------------------------------------------------------
%% 4 SAVE PARAMETERS AND STEADY STATE
    save parameterfile.mat beta sigma chi nu alpha delta ra sa Ass gamma; 
    save steadystate.mat ns rs Ass ys cs is ks lbs ws rs; 
%--------------------------------------------------------------------------
%% 5 RUN THE DYNARE FILE
if Sett.model == 1 
    dynare rbc_growth_1 noclearall
    my_results_1=oo_;
    save('my_results_1.mat');
else 
    dynare rbc_growth_2 noclearall
    my_results_2=oo_;
    save('my_results_2.mat');
end
end
%% 6 SPECIFIC PLOTTING
clear all 
clc
load my_results_1
load my_results_2
% Plot Settings
Sett.time=1:1:20;
%% 7 FIGURE MAIN 
%# centimeters units
X = 21.0;                  %# A4 paper size
Y = 10.5;                  %# A4 paper size
xMargin = 1;               %# left/right margins from page borders
yMargin = 1;               %# bottom/top margins from page borders
xSize = X - 2*xMargin;     %# figure size on paper (widht & hieght)
ySize = Y - 2*yMargin;     %# figure size on paper (widht & hieght)
%# create figure/axis
hFig =  figure('Name','Impulse Response Functions','Menubar','none');
subplot(1,2,1)
    % Output Model 1
    line1=plot(Sett.time,my_results_1.irfs.y_ea,'--mo','LineWidth',2);
    % Output Model 2
    hold on
    line2=plot(Sett.time,my_results_2.irfs.y_ea,'-.r*','LineWidth',2);
        hTitle = title(['Output'] );
        grid on 
        %axis([0 20 min(min(Mult_G_Y_cum)) max(max(Mult_G_Y_cum))]);
        hYLabel = ylabel('% deviation from steady state');
        hXLabel = xlabel('Periods');
    set(gca,...
    'FontSize',8, ...    
    'FontName','Palatino');
    set([hTitle, hYLabel, hXLabel], ...
    'FontName','Palatino');
    set([hTitle, hYLabel, hXLabel],...        
    'FontSize',8, ...
    'FontWeight','normal');

subplot(1,2,2)
    % Consumption Model 1
    line1=plot(Sett.time,my_results_1.irfs.c_ea,'--mo','LineWidth',2);
    % Consumption Model 2
    hold on
    line2=plot(Sett.time,my_results_2.irfs.c_ea,'-.r*','LineWidth',2);
        hTitle = title(['Consumption'] );
        grid on 
        %axis([0 20 min(min(Mult_G_Y_cum)) max(max(Mult_G_Y_cum))]);
        hYLabel = ylabel('% deviation from steady state');
        hXLabel = xlabel('Periods');
    set(gca,...
    'FontSize',8, ...    
    'FontName','Palatino');
    set([hTitle, hYLabel, hXLabel], ...
    'FontName','Palatino');
    set([hTitle, hYLabel, hXLabel],...        
    'FontSize',8, ...
    'FontWeight','normal');

% Construct a Legend with the data from the sub-plots
hL = legend([line1,line2],{'Model 1','Model 2'});
% Programatically move the Legend
newPosition = [0.05 0.05 0.05 0.05];
newUnits = 'normalized';
set(hL,'Position', newPosition,'Units', newUnits);

set(hFig, 'Units','centimeters', 'Position',[0 0 xSize ySize])
movegui(hFig, 'center')

%# figure size printed on paper
set(hFig, 'PaperUnits','centimeters')
set(hFig, 'PaperSize',[X Y])
set(hFig, 'PaperPosition',[xMargin yMargin xSize ySize])
set(hFig, 'PaperOrientation','portrait')

print -depsc -r0 results_irfs.eps
winopen results_irfs.eps