// RBC model with everything in logs
// Harrod neutral technological progress
// Utility function: c^(1-sigma)/(1-sigma)-chi*n^(1+nu)/(1+nu)
//-------------------------------------------------------------------------
// INITIATLIZE PROCESS
var y,c,i,k,n,lb,a,w,r; 	// Name of the variables
varexo ea;              	// Name of the exogenous variable
parameters beta,nu,sigma,chi,   // Preferences
alpha,delta,gamma,              // Technology
ra,sa,Ass;                      // Technology Shock

//-------------------------------------------------------------------------
// LOAD PARAMETER VALUES FROM MATRIX
load parameterfile.mat;
for i=1:length(M_.params)
    deep_parameter_name = M_.param_names(i,:);
    eval(['M_.params(i)  = ' deep_parameter_name ' ;'])
end
//-------------------------------------------------------------------------
// Equations of the model

model;
exp(-sigma*c)=exp(lb);                              	// Consumption
chi*exp(nu*n)=exp(lb+w);                            	// Labor supply
exp(lb)=beta/gamma*exp(lb(+1))*(exp(r(+1))+(1-delta));  // Euler equation
gamma*exp(k)=exp(i)+(1-delta)*exp(k(-1));               // Capital accumulation
exp(y)=exp(c)+exp(i);                               	// Market clearing
exp(y)=exp(a+alpha*k(-1)+(1-alpha)*n);              	// Production function
exp(w)=(1-alpha)*exp(a+y-n);                        	// Labor demand
exp(r)=alpha*exp(a+y-k(-1));                        	// Capital demand

a=(1-ra)*log(Ass)+ra*a(-1)+ea;                          // Supply Shock (in logs)
end;

//-------------------------------------------------------------------------
// LOAD STEADY STATE VALUES FROM MATRIX
load steadystate.mat;

initval;
ea = 0;
a = log(Ass);
y = log(ys);
c = log(cs);
i = log(is);
k = log(ks);
n = log(ns);
lb = log(lbs);
w = log(ws);
r = log(rs);
end;

steady;
check;

// Declaring the shocks
shocks;
var ea; stderr sa;
end;
// Launch solving procedure
stoch_simul(order=1,irf=20,hp_filter=1600) y,c,i,k,n,a;